@@ -6,6 +6,51 @@ class Crp:
     """
     """
 
+
+
+    def getCleanData(self,df):
+        """
+        Params: 
+            df-> Dataframe
+        -----------------------
+        Output: 
+            Clean dataframe after filtering
+            log_file - Desc of actions taken
+        """
+        log_file = []
+        # Clean cancelled orders 
+        df['cancelledat'] = df['cancelledat'].fillna('Valid')
+        df_1 = df[(df.cancelledat == 'Valid')]
+        
+        # Record canceled orders
+        canceled_orders_num = (len(df) - len(df_1))
+        
+        # Clean free orders 
+        free = df[(df.totaldiscounts == df.totalorderitemsprice) & (df.totalprice == 0)]
+        free_orders_num = len(free)
+            
+        log_file.append([canceled_orders_num,free_orders_num])
+        
+        # log file for documentation
+        log_file = pd.DataFrame(log_file,columns = ['Number_of_canceled_Orders','Number_of_free_orders'])
+        
+        
+        df_1 = df_1[~(df_1.id.isin(free['id'].values))]
+        
+        return df_1,log_file
+
+#-----------------------------------------------------------------------------------------------------------------------
+
+
+
+
+
+
+
+
+
+
+
     def getTrainingframe(self,df,dateFlag_sep,date_flag_min):
         """
         Params:
@@ -178,8 +223,9 @@ class Crp:
         
         """
         
-        # First, perform initial cleaning and save a log file of actions
-        # df,log_file = getCleanData(original_dataset)
+        # First, perform initial cleaning and save a log file of action
+    
+        df,log_file = getCleanData(original_dataset)
         # Get the first matrices
         train_data = self.getTrainingframe(df,dateFlag_sep,date_flag_min)
         print('train_data Done')
